<?php
/**
* Customizer default options
*
* @package Theme Palace
* @subpackage Teach Kiddo
* @since Teach Kiddo 1.0.0
* @return array An array of default values
*/

function teach_kiddo_get_default_theme_options() {
	$theme_data = wp_get_theme();
	$teach_kiddo_default_options = array(
		// Color Options
		'header_title_color'			=> '#2c2d39',
		'header_tagline_color'			=> '#990f12',
		'header_txt_logo_extra'			=> 'show-all',
		'colorscheme_hue'				=> '#990f12',
		'colorscheme'					=> 'default',
		'theme_version'					=> 'lite-version',
		'home_layout'					=> 'default-design',

		// typography Options
		'theme_typography' 				=> 'default',
		'body_theme_typography' 		=> 'default',

		// loader
		'loader_enable'         		=> (bool) false,
		'loader_icon'         			=> 'default',

		// banner
		'hide_single_page_banner'		=> (bool) true,
		'hide_single_post_banner'		=> (bool) true,

		// breadcrumb
		'breadcrumb_enable'				=> (bool) true,
		'breadcrumb_separator'			=> '/',

		// layout 
		'site_layout'         			=> 'wide-layout',
		'sidebar_position'         		=> 'right-sidebar',
		'post_sidebar_position' 		=> 'right-sidebar',
		'page_sidebar_position' 		=> 'right-sidebar',
		'menu_sticky'					=> (bool) true,
		'menu_search'					=> (bool) true,

		// excerpt options
		'long_excerpt_length'           => 25,

		// pagination options
		'pagination_enable'         	=> (bool) true,
		'pagination_type'         		=> 'default',

		// footer options
		'copyright_text'           		=> sprintf( esc_html_x( 'Copyright &copy; %1$s %2$s', '1: Year, 2: Site Title with home URL', 'teach-kiddo' ), '[the-year]', '[site-link]' ),
		'scroll_top_visible'        	=> (bool) true,

		// reset options
		'reset_options'      			=> (bool) false,

		// homepage options
		'enable_frontpage_content' 		=> (bool) false,

		// homepage sections sortable
		'all_sortable'	=> 'slider,service,popular_course,counter,team,testimonial,blog,contact',

		'default_sortable'	=> 'slider,service,popular_course,counter,team,testimonial,blog,contact',

		// blog/archive options
		'your_latest_posts_title' 		=> esc_html__( 'Blogs', 'teach-kiddo' ),
		'hide_date' 					=> (bool) false,
		'hide_image'					=> (bool) false,
		'hide_category'					=> (bool) false,
		'hide_author'					=> (bool) false,
		'hide_title'					=> (bool) false,
		'archive_btn_title'				=> esc_html__( 'Read More', 'teach-kiddo' ),

		// single post theme options
		'single_post_hide_date' 		=> (bool) false,
		'single_post_hide_author'		=> (bool) false,
		'single_post_hide_category'		=> (bool) false,
		'single_post_hide_tags'			=> (bool) false,
		'single_post_hide_image'		=> (bool) false,
		'single_post_hide_description'	=> (bool) false,

		/* Front Page */

		// topbar
		'topbar_section_enable'			=> (bool) false,
		'topbar_btn'					=> (bool) true,
		'social_menu_enable'			=> (bool) true,
		'topbar_btn_title'				=> esc_html__( 'Apply', 'teach-kiddo' ),
		'topbar_btn_url'				=> esc_html__( '#', 'teach-kiddo' ),
		'topbar_field_1'				=> esc_html__( ' 123 456 7891', 'teach-kiddo' ),
		'topbar_field_2'				=> esc_html__( 'info@enlightme.com', 'teach-kiddo' ),

		//menu
		'menu_btn_title'				=> esc_html__( 'Get Starts', 'teach-kiddo' ),
		'menu_btn_url'					=> '',

		// slider
		'slider_section_enable'			=> (bool) false,
		'slider_content_type'			=> 'post',
		'slider_autoplay'				=> (bool) false,
		'slider_count'					=> 3,
		'slider_excerpt_length'			=> 25,
		'slider_search_enable'			=> (bool)false,

		//service 
		'service_section_enable'		=> (bool) false,
		'service_content_type'			=> 'post',
		'service_title'					=> esc_html__( 'Learn From People Around you', 'teach-kiddo' ),
		'service_sub_title'				=> esc_html__( 'Get Started!', 'teach-kiddo' ),
		'service_description'			=> esc_html__( 'While college tuition more than tripled over the past 30 years, the value of a college degree gradually fell due to credential inflation. As more people get degrees, what used to be a unique achievement becomes trivial.', 'teach-kiddo' ),
		'service_btn'					=> esc_html__( 'Read More', 'teach-kiddo' ),
		'service_excerpt_length'		=> 20,

		// testimonial
		'testimonial_section_enable'					=> (bool) false,
		'testimonial_section_link_enable'				=> (bool) false,
		'testimonial_content_type'						=> 'page',
		'testimonial_excerpt_length'					=> 25,
		'testimonial_section_autoplay_slider_enable'	=> (bool) true,
		'testimonial_section_buttom_slider_enable'		=> (bool) true,
		'testimonial_sub_title'							=> esc_html__( 'Testimonials', 'teach-kiddo' ),
		'testimonial_title'								=> esc_html__( 'What Happy People Said About Enlightme', 'teach-kiddo' ),

		//popular course 
		'popular_course_section_enable'		=> false,
		'popular_course_content_type'		=> 'page',
		'popular_course_read_more'			=> esc_html__( 'Join Course', 'teach-kiddo' ),
		'popular_course_title'				=> esc_html__( 'Most Popular Courses', 'teach-kiddo' ),
		'popular_course_btn_title'			=> esc_html__( 'View All Courses', 'teach-kiddo' ),
		
		// blog
		'blog_section_enable'			=> (bool) false,
		'blog_content_type'				=> 'post',
		'blog_excerpt_length'			=> 25,
		'blog_title'					=> esc_html__( 'Know What’s Going on Around Us', 'teach-kiddo' ),

		//team 
		'team_section_enable'					=> (bool) false,
		'team_content_type'						=> 'page',
		'team_count'							=> 5,
		'team_section_autoplay_slider_enable'	=> (bool) true,
		'team_section_buttom_slider_enable'		=> (bool) true,
		'team_title'							=> esc_html__( 'Our Team Members', 'teach-kiddo' ),
		'team_sub_title'						=> esc_html__( 'We Are Family', 'teach-kiddo' ),	
		'team_button'							=> esc_html__( 'View Detail', 'teach-kiddo' ),	

		// counter
		'counter_section_enable'		=> (bool) false,
		'counter_count'					=> 4,
		'counter_column'				=> 'col-4',

		// contact 
		'contact_section_enable'        => (bool) false,
		'contact_title_1'				=> esc_html__( 'Contact Info', 'teach-kiddo' ),
		'contact_title_2'				=> esc_html__( 'Inquiry Form', 'teach-kiddo' ),

		//footer
		'footer_text'					=> esc_html__( 'Join thousands of learners making a difference every day using Enlightme.', 'teach-kiddo' ),
		'footer_btn_title'				=> esc_html__( 'Explore a free course', 'teach-kiddo' ),

		);

$output = apply_filters( 'teach_kiddo_default_theme_options', $teach_kiddo_default_options );

// Sort array in ascending order, according to the key:
if ( ! empty( $output ) ) {
	ksort( $output );
}

return $output;
}


