<?php
/**
* Blog Section options
*
* @package Theme Palace
* @subpackage Teach Kiddo
* @since Teach Kiddo 1.0.0
*/

// Add Blog section
$wp_customize->add_section( 'teach_kiddo_blog_section', array(
	'title'             => esc_html__( 'Blog','teach-kiddo' ),
	'description'       => esc_html__( 'Blog Section options.', 'teach-kiddo' ),
	'panel'             => 'teach_kiddo_front_page_panel',
	) );

// Blog content enable control and setting
$wp_customize->add_setting( 'teach_kiddo_theme_options[blog_section_enable]', array(
	'default'			=> 	$options['blog_section_enable'],
	'sanitize_callback' => 'teach_kiddo_sanitize_switch_control',
	) );

$wp_customize->add_control( new Teach_Kiddo_Switch_Control( $wp_customize, 'teach_kiddo_theme_options[blog_section_enable]', array(
	'label'             => esc_html__( 'Blog Section Enable', 'teach-kiddo' ),
	'section'           => 'teach_kiddo_blog_section',
	'on_off_label' 		=> teach_kiddo_switch_options(),
	) ) );
	
	if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'teach_kiddo_theme_options[blog_section_enable]', array(
		'selector'            => '#latest-posts .tooltiptext',
		'settings'            => 'teach_kiddo_theme_options[blog_section_enable]',
    ) );
}


// blog title setting and control
$wp_customize->add_setting( 'teach_kiddo_theme_options[blog_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['blog_title'],
	'transport'			=> 'postMessage',
	) );

$wp_customize->add_control( 'teach_kiddo_theme_options[blog_title]', array(
	'label'           	=> esc_html__( 'Title', 'teach-kiddo' ),
	'section'        	=> 'teach_kiddo_blog_section',
	'active_callback' 	=> 'teach_kiddo_is_blog_section_enable',
	'type'				=> 'text',
	) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
	$wp_customize->selective_refresh->add_partial( 'teach_kiddo_theme_options[blog_title]', array(
		'selector'            => '#latest-posts .section-title',
		'settings'            => 'teach_kiddo_theme_options[blog_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'teach_kiddo_blog_title_partial',
		) );
}


// long Excerpt length setting and control.
$wp_customize->add_setting( 'teach_kiddo_theme_options[blog_excerpt_length]', array(
	'sanitize_callback' => 'teach_kiddo_sanitize_number_range',
	'validate_callback' => 'teach_kiddo_validate_long_excerpt',
	'default'			=> $options['blog_excerpt_length'],
	) );

$wp_customize->add_control( 'teach_kiddo_theme_options[blog_excerpt_length]', array(
	'label'       		=> esc_html__( 'Blog Excerpt Length', 'teach-kiddo' ),
	'description' 		=> esc_html__( 'Total description words to be displayed in blog posts.', 'teach-kiddo' ),
	'section'     		=> 'teach_kiddo_blog_section',
	'active_callback' 	=> 'teach_kiddo_is_blog_section_enable',
	'type'        		=> 'number',
	'input_attrs' 		=> array(
		'style'       => 'width: 80px;',
		'max'         => 100,
		'min'         => 5,
		),
	) );

// Blog content type control and setting
$wp_customize->add_setting( 'teach_kiddo_theme_options[blog_content_type]', array(
	'default'          	=> $options['blog_content_type'],
	'sanitize_callback' => 'teach_kiddo_sanitize_select',
	) );

$wp_customize->add_control( 'teach_kiddo_theme_options[blog_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'teach-kiddo' ),
	'section'           => 'teach_kiddo_blog_section',
	'type'				=> 'select',
	'active_callback' 	=> 'teach_kiddo_is_blog_section_enable',
	'choices'			=> array( 
		'post' 		=> esc_html__( 'Post', 'teach-kiddo' ),
		'category' 	=> esc_html__( 'Category', 'teach-kiddo' ),
		),
	) );


for ( $i = 1; $i <= 3; $i++ ) :


// blog posts drop down chooser control and setting
$wp_customize->add_setting( 'teach_kiddo_theme_options[blog_content_post_' . $i . ']', array(
	'sanitize_callback' => 'teach_kiddo_sanitize_page',
	) );

$wp_customize->add_control( new Teach_Kiddo_Dropdown_Chooser( $wp_customize, 'teach_kiddo_theme_options[blog_content_post_' . $i . ']', array(
	'label'             => sprintf( esc_html__( 'Select Post %d', 'teach-kiddo' ), $i ),
	'section'           => 'teach_kiddo_blog_section',
	'choices'			=> teach_kiddo_post_choices(),
	'active_callback'	=> 'teach_kiddo_is_blog_section_content_post_enable',
	) ) );
endfor;

// Add dropdown category setting and control.
$wp_customize->add_setting(  'teach_kiddo_theme_options[blog_content_category]', array(
	'sanitize_callback' => 'teach_kiddo_sanitize_single_category',
	) ) ;

$wp_customize->add_control( new Teach_Kiddo_Dropdown_Taxonomies_Control( $wp_customize,'teach_kiddo_theme_options[blog_content_category]', array(
	'label'             => esc_html__( 'Select Category', 'teach-kiddo' ),
	'description'      	=> esc_html__( 'Note: Latest selected no of posts will be shown from selected category', 'teach-kiddo' ),
	'section'           => 'teach_kiddo_blog_section',
	'type'              => 'dropdown-taxonomies',
	'active_callback'	=> 'teach_kiddo_is_blog_section_content_category_enable'
	) ) );

