<?php
/**
 * Courses Section options
 *
 * @package Theme Palace
 * @subpackage Teach Kiddo
 * @since Teach Kiddo 1.0.0
 */

// Add Courses section
$wp_customize->add_section( 'teach_kiddo_popular_course_section', array(
	'title'             => esc_html__( 'Popular Courses','teach-kiddo' ),
	'panel'             => 'teach_kiddo_front_page_panel',
) );

// Courses content enable control and setting
$wp_customize->add_setting( 'teach_kiddo_theme_options[popular_course_section_enable]', array(
	'default'			=> 	$options['popular_course_section_enable'],
	'sanitize_callback' => 'teach_kiddo_sanitize_switch_control',
) );

$wp_customize->add_control( new Teach_Kiddo_Switch_Control( $wp_customize, 'teach_kiddo_theme_options[popular_course_section_enable]', array(
	'label'             => esc_html__( 'Course Section Enable', 'teach-kiddo' ),
	'section'           => 'teach_kiddo_popular_course_section',
	'on_off_label' 		=> teach_kiddo_switch_options(),
) ) );

if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'teach_kiddo_theme_options[popular_course_section_enable]', array(
		'selector'            => '#popular-courses .tooltiptext',
		'settings'            => 'teach_kiddo_theme_options[popular_course_section_enable]',
    ) );
}

// course title setting and control
$wp_customize->add_setting( 'teach_kiddo_theme_options[popular_course_title]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['popular_course_title'],
	'transport'			=> 'postMessage',
) );

$wp_customize->add_control( 'teach_kiddo_theme_options[popular_course_title]', array(
	'label'           	=> esc_html__( 'Title', 'teach-kiddo' ),
	'section'        	=> 'teach_kiddo_popular_course_section',
	'active_callback' 	=> 'teach_kiddo_is_popular_course_section_enable',
	'type'				=> 'text',
) );

// Abort if selective refresh is not available.
if ( isset( $wp_customize->selective_refresh ) ) {
    $wp_customize->selective_refresh->add_partial( 'teach_kiddo_theme_options[popular_course_title]', array(
		'selector'            => '#popular-courses .section-header h2',
		'settings'            => 'teach_kiddo_theme_options[popular_course_title]',
		'container_inclusive' => false,
		'fallback_refresh'    => true,
		'render_callback'     => 'teach_kiddo_popular_course_title_partial',
    ) );
}

// course btn title setting and control
$wp_customize->add_setting( 'teach_kiddo_theme_options[popular_course_read_more]', array(
	'sanitize_callback' => 'sanitize_text_field',
	'default'			=> $options['popular_course_read_more'],
) );

$wp_customize->add_control( 'teach_kiddo_theme_options[popular_course_read_more]', array(
	'label'           	=> esc_html__( 'Read More Label', 'teach-kiddo' ),
	'section'        	=> 'teach_kiddo_popular_course_section',
	'active_callback' 	=> 'teach_kiddo_is_popular_course_section_enable',
	'type'				=> 'text',
) );


// Courses content type control and setting
$wp_customize->add_setting( 'teach_kiddo_theme_options[popular_course_content_type]', array(
	'default'          	=> $options['popular_course_content_type'],
	'sanitize_callback' => 'teach_kiddo_sanitize_select',
) );

$wp_customize->add_control( 'teach_kiddo_theme_options[popular_course_content_type]', array(
	'label'             => esc_html__( 'Content Type', 'teach-kiddo' ),
	'section'           => 'teach_kiddo_popular_course_section',
	'type'				=> 'select',
	'active_callback' 	=> 'teach_kiddo_is_popular_course_section_enable',
	'choices'			=> teach_kiddo_popular_course_content_type(),
) );

for ( $i = 1; $i <= 3; $i++ ) :

	// course pages drop down chooser control and setting
	$wp_customize->add_setting( 'teach_kiddo_theme_options[popular_course_content_page_' . $i . ']', array(
		'sanitize_callback' => 'teach_kiddo_sanitize_page',
	) );

	$wp_customize->add_control( new Teach_Kiddo_Dropdown_Chooser( $wp_customize, 'teach_kiddo_theme_options[popular_course_content_page_' . $i . ']', array(
		'label'             => sprintf( esc_html__( 'Select Page %d', 'teach-kiddo' ), $i ),
		'section'           => 'teach_kiddo_popular_course_section',
		'choices'			=> teach_kiddo_page_choices(),
		'active_callback'	=> 'teach_kiddo_is_popular_course_section_content_page_enable',
	) ) );	

	if ( class_exists( 'TP_Education' ) ) {
		// course pages drop down chooser control and setting
		$wp_customize->add_setting( 'teach_kiddo_theme_options[popular_course_content_course_' . $i . ']', array(
			'sanitize_callback' => 'teach_kiddo_sanitize_page',
		) );

		$wp_customize->add_control( new Teach_Kiddo_Dropdown_Chooser( $wp_customize, 'teach_kiddo_theme_options[popular_course_content_course_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Course %d', 'teach-kiddo' ), $i ),
			'section'           => 'teach_kiddo_popular_course_section',
			'choices'			=> teach_kiddo_course_choices(),
			'active_callback'	=> 'teach_kiddo_is_popular_course_section_content_course_enable',
		) ) );		
	}

	if ( class_exists( 'TP_Education' ) ) {
		// course pages drop down chooser control and setting
		$wp_customize->add_setting( 'teach_kiddo_theme_options[popular_course_content_course_' . $i . ']', array(
			'sanitize_callback' => 'teach_kiddo_sanitize_page',
		) );

		$wp_customize->add_control( new Teach_Kiddo_Dropdown_Chooser( $wp_customize, 'teach_kiddo_theme_options[popular_course_content_course_' . $i . ']', array(
			'label'             => sprintf( esc_html__( 'Select Course %d', 'teach-kiddo' ), $i ),
			'section'           => 'teach_kiddo_popular_course_section',
			'choices'			=> teach_kiddo_course_choices(),
			'active_callback'	=> 'teach_kiddo_is_popular_course_section_content_course_enable',
		) ) );		
	}


	// course hr setting and control
	$wp_customize->add_setting( 'teach_kiddo_theme_options[popular_course_hr_'. $i .']', array(
		'sanitize_callback' => 'sanitize_text_field'
	) );

	$wp_customize->add_control( new Teach_Kiddo_Customize_Horizontal_Line( $wp_customize, 'teach_kiddo_theme_options[popular_course_hr_'. $i .']',
		array(
			'section'         => 'teach_kiddo_popular_course_section',
			'type'			  => 'hr'
	) ) );
endfor;
